/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU8 tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA;
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
static N_INLINE(NIM_BOOL, isEmptyType__ast_4780)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGarbageCollectedRef__types_612)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA, spawnResult__spawn_34)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL inParallel);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeIT__ast_3342)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___renderer_2116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getSysType__magicsys_60)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5340)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5302)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5347)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5345)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5296)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, createObj__lowerings_293)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NIM_BOOL final);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, createCastExpr__spawn_293)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* argsParam, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_4276)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, addVar__lowerings_63)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, addField__lowerings_420)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newFastAsgnStmt__lowerings_93)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newDotExpr__lowerings_478)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* obj, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, indirectAccess__lowerings_616)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* b, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, setupArgsForConcurrency__spawn_310)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* scratchObj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* castExpr, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, addLocalVar__spawn_83)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v, NIM_BOOL useShallowCopy);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3324)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI children);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newFastMoveStmt__lowerings_99)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, typeNeedsNoDeepCopy__spawn_68)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getSysMagic__magicsys_29)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* name, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(void, setupArgsForParallelism__spawn_380)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* scratchObj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* castExpr, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createMagic__modulegraphs_9046)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, NimStringDesc* name, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag, getMagic__trees_137)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, genAddrOf__lowerings_626)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg typeKind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, genHigh__lowerings_706)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntLit__lowerings_701)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI64 value);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, genDeref__lowerings_632)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw k);
N_LIB_PRIVATE N_NIMCALL(NI64, computeSize__types_3369)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getRoot__trees_390)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getCompilerProc__magicsys_145)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, callProc__spawn_12)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, callCodegenProc__lowerings_641)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NimStringDesc* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg1, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg2, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg3, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* optionalArgs);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__liftdestructors_47)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* orig, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(void, createWrapperProc__spawn_137)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadParam, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* argsParam, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fv, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA spawnKind, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newAsgnStmt__lowerings_87)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, indirectAccess__lowerings_542)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, NimStringDesc* b, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA, flowVarKind__spawn_47)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newProcNode__ast_3809)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* name, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pattern, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* genericParams, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmas, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* exceptions);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_2, "(", 1);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_3, ", ", 2);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_4, ")", 1);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_6, "/home/runner/work/nightlies/nightlies/nim/compiler/spawn.nim", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_5 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 327),
((NI) 19)}
;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_7 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 330),
((NI) 19)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_8, "\'spawn\' must not be discarded", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_9 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 333),
((NI) 30)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_10, "\'spawn\' takes a call expression; got: ", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_11 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 337),
((NI) 14)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_12, "\'spawn\' takes a GC safe call expression", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_13 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 341),
((NI) 16)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_14, ":tmp", 4);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_15, "Wrapper", 7);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_16, "thread", 6);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_17, "args", 4);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_18, "scratch", 7);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_19, "closure in spawn environment is not allowed", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_20 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 373),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__Cdo77GqyHVvb4CeKFFZ13Q_21 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_22, "fn", 2);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_23, "iterator in spawn environment is not allowed", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_24 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 384),
((NI) 14)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_25, "\'spawn\'ed function cannot have a \'var\' parameter", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_26 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 212),
((NI) 18)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_27, "\'spawn\'ed function cannot have a \'typed\' or \'untyped\' parameter", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_28 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 198),
((NI) 14)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_29, "deepCopy", 8);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_30, "slice", 5);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_31, "Barrier", 7);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_32, "barrier", 7);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_33, "fv", 2);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_34, "nimFlowVarCreateSemaphore", 25);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_35, "barrierEnter", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_36 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 129),
((NI) 19)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_37, "owner", 5);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_38, "nimArgsPassingDone", 18);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_39, "cannot create a flowVar of type: ", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Cdo77GqyHVvb4CeKFFZ13Q_40 = {((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_6),
((NI) 146),
((NI) 16)}
;
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_41, "data", 4);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_42, "blob", 4);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_43, "GCref", 5);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_44, "nimFlowVarSignal", 16);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_45, "barrierLeave", 12);
STRING_LITERAL(TM__Cdo77GqyHVvb4CeKFFZ13Q_46, "nimSpawn", 8);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5249;
static N_INLINE(NIM_BOOL, isEmptyType__ast_4780)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA, spawnResult__spawn_34)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL inParallel) {
	tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA result;
	result = (tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmptyType__ast_4780(t);
		if (!T3_) goto LA4_;
		result = ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 0);
	}
	goto LA1_;
	LA4_: ;
	{
		NIM_BOOL T7_;
		NIM_BOOL T9_;
		T7_ = (NIM_BOOL)0;
		T7_ = inParallel;
		if (!(T7_)) goto LA8_;
		T9_ = (NIM_BOOL)0;
		T9_ = containsGarbageCollectedRef__types_612(t);
		T7_ = !(T9_);
		LA8_: ;
		if (!T7_) goto LA10_;
		result = ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 2);
	}
	goto LA1_;
	LA10_: ;
	{
		result = ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 1);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_2));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_3));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_4));
	}
	LA3_: ;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5340)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5302)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5345)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5296((&gch__system_5249.zct), c);
}
static N_INLINE(void, decRef__system_5347)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5345(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5302(src);
		incRef__system_5340(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5302((*dest));
		decRef__system_5347(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, createCastExpr__spawn_293)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* argsParam, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T2_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T3_;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61), (*argsParam).info);
	T1_ = NIM_NIL;
	T1_ = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1), (*argsParam).info);
	add__ast_4798(result, T1_);
	T2_ = NIM_NIL;
	T2_ = newSymNode__ast_3704(argsParam);
	add__ast_4798(result, T2_);
	T3_ = nextTypeId__ast_3122(idgen);
	asgnRef((void**) (&(*result).typ), newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21), T3_, (*objType).owner));
	rawAddSon__ast_4276((*result).typ, objType, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, typeNeedsNoDeepCopy__spawn_68)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
	NIM_BOOL T9_;
{	result = (NIM_BOOL)0;
	t_2 = skipTypes__ast_3723(t, TM__Cdo77GqyHVvb4CeKFFZ13Q_21);
	{
		if (!((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28))) goto LA3_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24))) goto LA7_;
		t_2 = lastSon__ast_3731(t_2);
	}
	LA7_: ;
	T9_ = (NIM_BOOL)0;
	T9_ = containsGarbageCollectedRef__types_612(t_2);
	result = !(T9_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, addLocalVar__spawn_83)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v, NIM_BOOL useShallowCopy) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T1_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T2_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* vpart;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_14));
	T2_ = nextSymId__ast_3103(idgen);
	result = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5), T1_, T2_, owner, (*varSection).info, (*owner).options);
	asgnRef((void**) (&(*result).typ), typ);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2)) & 63);
	vpart = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 35), (*varSection).info, ((NI) 3));
	asgnRef((void**) (&(*vpart)._kind_6.sons->data[((NI) 0)]), newSymNode__ast_3704(result));
	asgnRef((void**) (&(*vpart)._kind_6.sons->data[((NI) 1)]), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1), (*varSection).info));
	{
		if (!(varInit == 0)) goto LA5_;
		asgnRef((void**) (&(*vpart)._kind_6.sons->data[((NI) 2)]), v);
	}
	goto LA3_;
	LA5_: ;
	{
		asgnRef((void**) (&(*vpart)._kind_6.sons->data[((NI) 2)]), (*vpart)._kind_6.sons->data[((NI) 1)]);
	}
	LA3_: ;
	add__ast_4798(varSection, vpart);
	{
		if (!!((varInit == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA10_;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T16_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T17_;
			if (!((48 &((NU16)1<<((NU)((*(*g).config).selectedGC)&15U)))!=0)) goto LA14_;
			T16_ = NIM_NIL;
			T16_ = newSymNode__ast_3704(result);
			T17_ = NIM_NIL;
			T17_ = newFastMoveStmt__lowerings_99(g, T16_, v);
			add__ast_4798(varInit, T17_);
		}
		goto LA12_;
		LA14_: ;
		{
			{
				NIM_BOOL T21_;
				NIM_BOOL T22_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T27_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T28_;
				T21_ = (NIM_BOOL)0;
				T22_ = (NIM_BOOL)0;
				T22_ = useShallowCopy;
				if (!(T22_)) goto LA23_;
				T22_ = typeNeedsNoDeepCopy__spawn_68(typ);
				LA23_: ;
				T21_ = T22_;
				if (T21_) goto LA24_;
				T21_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0);
				LA24_: ;
				if (!T21_) goto LA25_;
				T27_ = NIM_NIL;
				T27_ = newSymNode__ast_3704(result);
				T28_ = NIM_NIL;
				T28_ = newFastMoveStmt__lowerings_99(g, T27_, v);
				add__ast_4798(varInit, T28_);
			}
			goto LA19_;
			LA25_: ;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* deepCopyCall;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T30_;
				deepCopyCall = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*varInit).info, ((NI) 3));
				T30_ = NIM_NIL;
				T30_ = getSysMagic__magicsys_29(g, (*varSection).info, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_29), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 200));
				asgnRef((void**) (&(*deepCopyCall)._kind_6.sons->data[((NI) 0)]), newSymNode__ast_3704(T30_));
				asgnRef((void**) (&(*deepCopyCall)._kind_6.sons->data[((NI) 1)]), newSymNode__ast_3704(result));
				asgnRef((void**) (&(*deepCopyCall)._kind_6.sons->data[((NI) 2)]), v);
				add__ast_4798(varInit, deepCopyCall);
			}
			LA19_: ;
		}
		LA12_: ;
	}
	LA10_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setupArgsForConcurrency__spawn_310)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* scratchObj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* castExpr, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* formals;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* tmpName;
	formals = (*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).n;
	tmpName = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_14));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* argType;
					tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* fieldname;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
					tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T32_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T33_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T34_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T35_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* temp;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T36_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T37_;
					argType = skipTypes__ast_3723((*(*n)._kind_6.sons->data[i]).typ, TM__Cdo77GqyHVvb4CeKFFZ13Q_21);
					{
						NI T7_;
						T7_ = (NI)0;
						T7_ = len__ast_3155(formals);
						if (!(i < T7_)) goto LA8_;
						{
							if (!((*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47))) goto LA12_;
							liMessage__msgs_1128((*g).config, (*(*n)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_25), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_26, NIM_FALSE);
						}
						LA12_: ;
						{
							NIM_BOOL T16_;
							NIM_BOOL T17_;
							T16_ = (NIM_BOOL)0;
							T17_ = (NIM_BOOL)0;
							T17_ = ((*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48));
							if (!(T17_)) goto LA18_;
							T17_ = ((*(*(*(*formals)._kind_6.sons->data[i]).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7) || (*(*(*(*formals)._kind_6.sons->data[i]).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6));
							LA18_: ;
							T16_ = T17_;
							if (T16_) goto LA19_;
							T16_ = ((*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7) || (*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6));
							LA19_: ;
							if (!T16_) goto LA20_;
							liMessage__msgs_1128((*g).config, (*(*n)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_27), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_28, NIM_FALSE);
						}
						LA20_: ;
						{
							if (!((*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8) || (*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA24_;
							goto LA4;
						}
						LA24_: ;
					}
					LA8_: ;
					{
						NI T28_;
						T28_ = (NI)0;
						T28_ = len__ast_3155(formals);
						if (!(i < T28_)) goto LA29_;
						fieldname = (*(*(*formals)._kind_6.sons->data[i])._kind_4.sym).name;
					}
					goto LA26_;
					LA29_: ;
					{
						fieldname = tmpName;
					}
					LA26_: ;
					T32_ = nextSymId__ast_3103(idgen);
					field = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), fieldname, T32_, (*objType).owner, (*n).info, (*(*g).config).options);
					asgnRef((void**) (&(*field).typ), argType);
					T33_ = NIM_NIL;
					T33_ = addField__lowerings_420(objType, field, (*g).cache, idgen);
					(void)(T33_);
					T34_ = NIM_NIL;
					T34_ = newDotExpr__lowerings_478(scratchObj, field);
					T35_ = NIM_NIL;
					T35_ = newFastAsgnStmt__lowerings_93(T34_, (*n)._kind_6.sons->data[i]);
					add__ast_4798(result, T35_);
					T36_ = NIM_NIL;
					T36_ = indirectAccess__lowerings_616(castExpr, field, (*n).info);
					temp = addLocalVar__spawn_83(g, varSection, varInit, idgen, owner, argType, T36_, NIM_FALSE);
					T37_ = NIM_NIL;
					T37_ = newSymNode__ast_3704(temp);
					add__ast_4798(call, T37_);
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, setupArgsForParallelism__spawn_380)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* scratchObj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* castExpr, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* formals;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* tmpName;
	formals = (*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).n;
	tmpName = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_14));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* argType;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T20_;
					tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* fieldname;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
					tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T33_;
					n_2 = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T7_;
						NI T8_;
						T7_ = (NIM_BOOL)0;
						T8_ = (NI)0;
						T8_ = len__ast_3155(formals);
						T7_ = (i < T8_);
						if (!(T7_)) goto LA9_;
						T7_ = ((*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60) || (*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8));
						LA9_: ;
						if (!T7_) goto LA10_;
						goto LA4;
					}
					LA10_: ;
					{
						NIM_BOOL T14_;
						NIM_BOOL T15_;
						T14_ = (NIM_BOOL)0;
						T15_ = (NIM_BOOL)0;
						T15_ = ((*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48));
						if (!(T15_)) goto LA16_;
						T15_ = ((*(*(*(*formals)._kind_6.sons->data[i]).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7) || (*(*(*(*formals)._kind_6.sons->data[i]).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6));
						LA16_: ;
						T14_ = T15_;
						if (T14_) goto LA17_;
						T14_ = ((*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7) || (*(*(*formals)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6));
						LA17_: ;
						if (!T14_) goto LA18_;
						liMessage__msgs_1128((*g).config, (*n_2).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_27), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_28, NIM_FALSE);
					}
					LA18_: ;
					T20_ = NIM_NIL;
					{
						NI T23_;
						T23_ = (NI)0;
						T23_ = len__ast_3155(formals);
						if (!(i < T23_)) goto LA24_;
						T20_ = (*(*formals)._kind_6.sons->data[i]).typ;
					}
					goto LA21_;
					LA24_: ;
					{
						T20_ = (*n_2).typ;
					}
					LA21_: ;
					argType = skipTypes__ast_3723(T20_, TM__Cdo77GqyHVvb4CeKFFZ13Q_21);
					{
						NI T29_;
						T29_ = (NI)0;
						T29_ = len__ast_3155(formals);
						if (!(i < T29_)) goto LA30_;
						fieldname = (*(*(*formals)._kind_6.sons->data[i])._kind_4.sym).name;
					}
					goto LA27_;
					LA30_: ;
					{
						fieldname = tmpName;
					}
					LA27_: ;
					T33_ = nextSymId__ast_3103(idgen);
					field = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), fieldname, T33_, (*objType).owner, (*n_2).info, (*(*g).config).options);
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* slice;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T38_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fieldB;
						tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T39_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T40_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T63_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadLocal_2;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T64_;
						if (!((*argType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48) || (*argType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27))) goto LA36_;
						slice = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*n_2).info, ((NI) 4));
						asgnRef((void**) (&(*slice).typ), (*n_2).typ);
						T38_ = NIM_NIL;
						T38_ = createMagic__modulegraphs_9046(g, idgen, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_30), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126));
						asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 0)]), newSymNode__ast_3704(T38_));
						asgnRef((void**) (&(*(*slice)._kind_6.sons->data[((NI) 0)]).typ), getSysType__magicsys_60(g, (*n_2).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31)));
						T39_ = nextSymId__ast_3103(idgen);
						fieldB = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), tmpName, T39_, (*objType).owner, (*n_2).info, (*(*g).config).options);
						asgnRef((void**) (&(*fieldB).typ), getSysType__magicsys_60(g, (*n_2).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31)));
						T40_ = NIM_NIL;
						T40_ = addField__lowerings_420(objType, fieldB, (*g).cache, idgen);
						(void)(T40_);
						{
							tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T43_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T46_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T47_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T48_;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fieldA;
							tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T49_;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T50_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T51_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T52_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T53_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T54_;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadLocal_1;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T55_;
							T43_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
							T43_ = getMagic__trees_137(n_2);
							if (!(T43_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126))) goto LA44_;
							a = genAddrOf__lowerings_626((*n_2)._kind_6.sons->data[((NI) 1)], idgen, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
							asgnRef((void**) (&(*field).typ), (*a).typ);
							T46_ = NIM_NIL;
							T46_ = addField__lowerings_420(objType, field, (*g).cache, idgen);
							(void)(T46_);
							T47_ = NIM_NIL;
							T47_ = newDotExpr__lowerings_478(scratchObj, field);
							T48_ = NIM_NIL;
							T48_ = newFastAsgnStmt__lowerings_93(T47_, a);
							add__ast_4798(result, T48_);
							T49_ = nextSymId__ast_3103(idgen);
							fieldA = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), tmpName, T49_, (*objType).owner, (*n_2).info, (*(*g).config).options);
							asgnRef((void**) (&(*fieldA).typ), getSysType__magicsys_60(g, (*n_2).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31)));
							T50_ = NIM_NIL;
							T50_ = addField__lowerings_420(objType, fieldA, (*g).cache, idgen);
							(void)(T50_);
							T51_ = NIM_NIL;
							T51_ = newDotExpr__lowerings_478(scratchObj, fieldA);
							T52_ = NIM_NIL;
							T52_ = newFastAsgnStmt__lowerings_93(T51_, (*n_2)._kind_6.sons->data[((NI) 2)]);
							add__ast_4798(result, T52_);
							T53_ = NIM_NIL;
							T53_ = newDotExpr__lowerings_478(scratchObj, fieldB);
							T54_ = NIM_NIL;
							T54_ = newFastAsgnStmt__lowerings_93(T53_, (*n_2)._kind_6.sons->data[((NI) 3)]);
							add__ast_4798(result, T54_);
							T55_ = NIM_NIL;
							T55_ = indirectAccess__lowerings_616(castExpr, fieldA, (*n_2).info);
							threadLocal_1 = addLocalVar__spawn_83(g, varSection, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), idgen, owner, (*fieldA).typ, T55_, NIM_TRUE);
							asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 2)]), newSymNode__ast_3704(threadLocal_1));
						}
						goto LA41_;
						LA44_: ;
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_2;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T57_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T58_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T59_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T60_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T61_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T62_;
							a_2 = genAddrOf__lowerings_626(n_2, idgen, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
							asgnRef((void**) (&(*field).typ), (*a_2).typ);
							T57_ = NIM_NIL;
							T57_ = addField__lowerings_420(objType, field, (*g).cache, idgen);
							(void)(T57_);
							T58_ = NIM_NIL;
							T58_ = newDotExpr__lowerings_478(scratchObj, field);
							T59_ = NIM_NIL;
							T59_ = newFastAsgnStmt__lowerings_93(T58_, a_2);
							add__ast_4798(result, T59_);
							T60_ = NIM_NIL;
							T60_ = newDotExpr__lowerings_478(scratchObj, fieldB);
							T61_ = NIM_NIL;
							T61_ = genHigh__lowerings_706(g, n_2);
							T62_ = NIM_NIL;
							T62_ = newFastAsgnStmt__lowerings_93(T60_, T61_);
							add__ast_4798(result, T62_);
							asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 2)]), newIntLit__lowerings_701(g, (*n_2).info, IL64(0)));
						}
						LA41_: ;
						T63_ = NIM_NIL;
						T63_ = indirectAccess__lowerings_616(castExpr, field, (*n_2).info);
						asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 1)]), genDeref__lowerings_632(T63_, ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65)));
						T64_ = NIM_NIL;
						T64_ = indirectAccess__lowerings_616(castExpr, fieldB, (*n_2).info);
						threadLocal_2 = addLocalVar__spawn_83(g, varSection, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), idgen, owner, (*fieldB).typ, T64_, NIM_TRUE);
						asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 3)]), newSymNode__ast_3704(threadLocal_2));
						add__ast_4798(call, slice);
					}
					goto LA34_;
					LA36_: ;
					{
						NIM_BOOL T66_;
						NI64 size;
						NIM_BOOL T67_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T70_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_3;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T73_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T74_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T75_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadLocal_3;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T76_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T77_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T78_;
						T66_ = (NIM_BOOL)0;
						size = computeSize__types_3369((*g).config, argType);
						T67_ = (NIM_BOOL)0;
						T67_ = (size < IL64(0));
						if (T67_) goto LA68_;
						T67_ = (IL64(16) < size);
						LA68_: ;
						T66_ = T67_;
						if (!(T66_)) goto LA69_;
						T70_ = NIM_NIL;
						T70_ = getRoot__trees_390(n_2);
						T66_ = !((T70_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
						LA69_: ;
						if (!T66_) goto LA71_;
						a_3 = genAddrOf__lowerings_626(n_2, idgen, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
						asgnRef((void**) (&(*field).typ), (*a_3).typ);
						T73_ = NIM_NIL;
						T73_ = addField__lowerings_420(objType, field, (*g).cache, idgen);
						(void)(T73_);
						T74_ = NIM_NIL;
						T74_ = newDotExpr__lowerings_478(scratchObj, field);
						T75_ = NIM_NIL;
						T75_ = newFastAsgnStmt__lowerings_93(T74_, a_3);
						add__ast_4798(result, T75_);
						T76_ = NIM_NIL;
						T76_ = indirectAccess__lowerings_616(castExpr, field, (*n_2).info);
						threadLocal_3 = addLocalVar__spawn_83(g, varSection, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), idgen, owner, (*field).typ, T76_, NIM_TRUE);
						T77_ = NIM_NIL;
						T77_ = newSymNode__ast_3704(threadLocal_3);
						T78_ = NIM_NIL;
						T78_ = genDeref__lowerings_632(T77_, ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65));
						add__ast_4798(call, T78_);
					}
					goto LA34_;
					LA71_: ;
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T80_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T81_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T82_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadLocal_4;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T83_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T84_;
						asgnRef((void**) (&(*field).typ), argType);
						T80_ = NIM_NIL;
						T80_ = addField__lowerings_420(objType, field, (*g).cache, idgen);
						(void)(T80_);
						T81_ = NIM_NIL;
						T81_ = newDotExpr__lowerings_478(scratchObj, field);
						T82_ = NIM_NIL;
						T82_ = newFastAsgnStmt__lowerings_93(T81_, n_2);
						add__ast_4798(result, T82_);
						T83_ = NIM_NIL;
						T83_ = indirectAccess__lowerings_616(castExpr, field, (*n_2).info);
						threadLocal_4 = addLocalVar__spawn_83(g, varSection, varInit, idgen, owner, (*field).typ, T83_, NIM_TRUE);
						T84_ = NIM_NIL;
						T84_ = newSymNode__ast_3704(threadLocal_4);
						add__ast_4798(call, T84_);
					}
					LA34_: ;
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, callProc__spawn_12)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*a).info);
	add__ast_4798(result, a);
	asgnRef((void**) (&(*result).typ), (*(*a).typ).sons->data[((NI) 0)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA, flowVarKind__spawn_47)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA result;
	result = (tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA)0;
	{
		if (!((48 &((NU16)1<<((NU)((*c).selectedGC)&15U)))!=0)) goto LA3_;
		result = ((tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA) 2);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		T6_ = NIM_NIL;
		T6_ = skipTypes__ast_3723(t, TM__Cdo77GqyHVvb4CeKFFZ13Q_21);
		if (!((*T6_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T6_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28) || (*T6_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24))) goto LA7_;
		result = ((tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA) 1);
	}
	goto LA1_;
	LA7_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = containsGarbageCollectedRef__types_612(t);
		if (!T10_) goto LA11_;
		result = ((tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA) 0);
	}
	goto LA1_;
	LA11_: ;
	{
		result = ((tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA) 2);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createWrapperProc__spawn_137)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadParam, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* argsParam, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fv, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA spawnKind, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadLocalBarrier;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadLocalProm;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T28_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T29_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T74_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T75_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T76_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T77_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T78_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T79_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T80_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T81_;
	body = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*f).info);
	threadLocalBarrier = NIM_NIL;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection2;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T5_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T6_;
		if (!!((barrier == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		varSection2 = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99), (*barrier).info);
		threadLocalBarrier = addLocalVar__spawn_83(g, varSection2, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), idgen, result, (*barrier).typ, barrier, NIM_FALSE);
		add__ast_4798(body, varSection2);
		T5_ = NIM_NIL;
		T5_ = newSymNode__ast_3704(threadLocalBarrier);
		T6_ = NIM_NIL;
		T6_ = callCodegenProc__lowerings_641(g, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_35), (*threadLocalBarrier).info, T5_, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		add__ast_4798(body, T6_);
	}
	LA3_: ;
	threadLocalProm = NIM_NIL;
	{
		if (!(spawnKind == ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 2))) goto LA9_;
		threadLocalProm = addLocalVar__spawn_83(g, varSection, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), idgen, result, (*fv).typ, fv, NIM_FALSE);
	}
	goto LA7_;
	LA9_: ;
	{
		if (!!((fv == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA12_;
		{
			NimStringDesc* argX60gensym16_;
			if (!!(((*(*fv).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11)))) goto LA16_;
			argX60gensym16_ = toFileLineCol__msgs_625(TM__Cdo77GqyHVvb4CeKFFZ13Q_36);
			internalErrorImpl__msgs_1441((*g).config, unknownLineInfo__lineinfos_284, argX60gensym16_, TM__Cdo77GqyHVvb4CeKFFZ13Q_36);
		}
		LA16_: ;
		threadLocalProm = addLocalVar__spawn_83(g, varSection, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), idgen, result, (*fv).typ, fv, NIM_FALSE);
	}
	goto LA7_;
	LA12_: ;
	LA7_: ;
	add__ast_4798(body, varSection);
	add__ast_4798(body, varInit);
	{
		NIM_BOOL T20_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T24_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T25_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T26_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T27_;
		T20_ = (NIM_BOOL)0;
		T20_ = !((fv == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (!(T20_)) goto LA21_;
		T20_ = !((spawnKind == ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 2)));
		LA21_: ;
		if (!T20_) goto LA22_;
		T24_ = NIM_NIL;
		T24_ = newSymNode__ast_3704(threadLocalProm);
		T25_ = NIM_NIL;
		T25_ = indirectAccess__lowerings_542(T24_, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_37), (*fv).info, (*g).cache);
		T26_ = NIM_NIL;
		T26_ = newSymNode__ast_3704(threadParam);
		T27_ = NIM_NIL;
		T27_ = newAsgnStmt__lowerings_87(T25_, T26_);
		add__ast_4798(body, T27_);
	}
	LA22_: ;
	T28_ = NIM_NIL;
	T28_ = newSymNode__ast_3704(threadParam);
	T29_ = NIM_NIL;
	T29_ = callCodegenProc__lowerings_641(g, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_38), (*threadParam).info, T28_, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	add__ast_4798(body, T29_);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T34_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T35_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T36_;
		if (!(spawnKind == ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 2))) goto LA32_;
		T34_ = NIM_NIL;
		T34_ = newSymNode__ast_3704(threadLocalProm);
		T35_ = NIM_NIL;
		T35_ = genDeref__lowerings_632(T34_, ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65));
		T36_ = NIM_NIL;
		T36_ = newAsgnStmt__lowerings_87(T35_, call);
		add__ast_4798(body, T36_);
	}
	goto LA30_;
	LA32_: ;
	{
		tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA fk;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T46_;
		NimStringDesc* T47_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T53_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T54_;
		if (!!((fv == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA38_;
		fk = flowVarKind__spawn_47((*g).config, (*(*fv).typ).sons->data[((NI) 1)]);
		{
			NimStringDesc* T44_;
			NimStringDesc* T45_;
			if (!(fk == ((tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA) 0))) goto LA42_;
			T44_ = NIM_NIL;
			T45_ = NIM_NIL;
			T45_ = typeToString__types_50((*(*fv).typ).sons->data[((NI) 1)], ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			T44_ = rawNewString((T45_ ? T45_->Sup.len : 0) + 33);
appendString(T44_, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_39));
appendString(T44_, T45_);
			liMessage__msgs_1128((*g).config, (*f).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T44_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_40, NIM_FALSE);
		}
		LA42_: ;
		T46_ = NIM_NIL;
		T46_ = newSymNode__ast_3704(threadLocalProm);
		T47_ = NIM_NIL;
		{
			if (!(fk == ((tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA) 1))) goto LA50_;
			T47_ = copyString(((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_41));
		}
		goto LA48_;
		LA50_: ;
		{
			T47_ = copyString(((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_42));
		}
		LA48_: ;
		T53_ = NIM_NIL;
		T53_ = indirectAccess__lowerings_542(T46_, T47_, (*fv).info, (*g).cache);
		T54_ = NIM_NIL;
		T54_ = newAsgnStmt__lowerings_87(T53_, call);
		add__ast_4798(body, T54_);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* incRefCall;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T59_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T60_;
			if (!(fk == ((tyEnum_TFlowVarKind__cIw07ORkMz0E0jbA9bJWUuA) 1))) goto LA57_;
			incRefCall = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*fv).info, ((NI) 2));
			T59_ = NIM_NIL;
			T59_ = getSysMagic__magicsys_29(g, (*fv).info, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_43), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 44));
			asgnRef((void**) (&(*incRefCall)._kind_6.sons->data[((NI) 0)]), newSymNode__ast_3704(T59_));
			T60_ = NIM_NIL;
			T60_ = newSymNode__ast_3704(threadLocalProm);
			asgnRef((void**) (&(*incRefCall)._kind_6.sons->data[((NI) 1)]), indirectAccess__lowerings_542(T60_, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_41), (*fv).info, (*g).cache));
			add__ast_4798(body, incRefCall);
		}
		LA57_: ;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T65_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T66_;
			if (!(barrier == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA63_;
			T65_ = NIM_NIL;
			T65_ = newSymNode__ast_3704(threadLocalProm);
			T66_ = NIM_NIL;
			T66_ = callCodegenProc__lowerings_641(g, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_44), (*threadLocalProm).info, T65_, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
			add__ast_4798(body, T66_);
		}
		LA63_: ;
	}
	goto LA30_;
	LA38_: ;
	{
		add__ast_4798(body, call);
	}
	LA30_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T72_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T73_;
		if (!!((barrier == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA70_;
		T72_ = NIM_NIL;
		T72_ = newSymNode__ast_3704(threadLocalBarrier);
		T73_ = NIM_NIL;
		T73_ = callCodegenProc__lowerings_641(g, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_45), (*threadLocalBarrier).info, T72_, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		add__ast_4798(body, T73_);
	}
	LA70_: ;
	params = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76), (*f).info);
	T74_ = NIM_NIL;
	T74_ = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1), (*f).info);
	add__ast_4798(params, T74_);
	T75_ = NIM_NIL;
	T75_ = newSymNode__ast_3704(threadParam);
	add__ast_4798(params, T75_);
	T76_ = NIM_NIL;
	T76_ = newSymNode__ast_3704(argsParam);
	add__ast_4798(params, T76_);
	T77_ = nextTypeId__ast_3122(idgen);
	t = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25), T77_, (*threadParam).owner);
	rawAddSon__ast_4276(t, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL), NIM_TRUE);
	rawAddSon__ast_4276(t, (*threadParam).typ, NIM_TRUE);
	rawAddSon__ast_4276(t, (*argsParam).typ, NIM_TRUE);
	asgnRef((void**) (&(*t).n), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76), (*f).info));
	T78_ = NIM_NIL;
	T78_ = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*f).info);
	add__ast_4798((*t).n, T78_);
	T79_ = NIM_NIL;
	T79_ = newSymNode__ast_3704(threadParam);
	add__ast_4798((*t).n, T79_);
	T80_ = NIM_NIL;
	T80_ = newSymNode__ast_3704(argsParam);
	add__ast_4798((*t).n, T80_);
	emptyNode = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1), (*f).info);
	T81_ = NIM_NIL;
	T81_ = newSymNode__ast_3704(result);
	asgnRef((void**) (&(*result).ast), newProcNode__ast_3809(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79), (*f).info, body, params, T81_, emptyNode, emptyNode, emptyNode, emptyNode));
	asgnRef((void**) (&(*result).typ), t);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, wrapProcForSpawn__spawn_510)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spawnExpr, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* retType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	NI T1_;
	tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA spawnKind;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fn;
	NimStringDesc* name;
	NimStringDesc* T31_;
	NimStringDesc* T32_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* wrapperProc;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T38_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T39_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* threadParam;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T40_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T41_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* argsParam;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T42_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T43_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* castExpr;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* scratchObj;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T45_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T46_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varInit;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrierAsExpr;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fvField;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fvAsExpr;
	NimStringDesc* T114_;
	NI T115_;
	NimStringDesc* T116_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T117_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T118_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T119_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T120_;
{	result = NIM_NIL;
	T1_ = (NI)0;
	T1_ = len__ast_3155(spawnExpr);
	n = (*spawnExpr)._kind_6.sons->data[(NI)(T1_ - ((NI) 2))];
	spawnKind = spawnResult__spawn_34(retType, !((barrier == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))));
	switch (spawnKind) {
	case ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 0):
	{
		{
			NimStringDesc* argX60gensym76_;
			if (!!((dest == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA5_;
			argX60gensym76_ = toFileLineCol__msgs_625(TM__Cdo77GqyHVvb4CeKFFZ13Q_5);
			internalErrorImpl__msgs_1441((*g).config, unknownLineInfo__lineinfos_284, argX60gensym76_, TM__Cdo77GqyHVvb4CeKFFZ13Q_5);
		}
		LA5_: ;
		result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n).info);
	}
	break;
	case ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 1):
	{
		{
			NimStringDesc* argX60gensym78_;
			if (!!((dest == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA10_;
			argX60gensym78_ = toFileLineCol__msgs_625(TM__Cdo77GqyHVvb4CeKFFZ13Q_7);
			internalErrorImpl__msgs_1441((*g).config, unknownLineInfo__lineinfos_284, argX60gensym78_, TM__Cdo77GqyHVvb4CeKFFZ13Q_7);
		}
		LA10_: ;
		result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126), (*n).info, retType);
	}
	break;
	case ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 2):
	{
		{
			if (!(dest == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA15_;
			liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_8), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_9, NIM_FALSE);
		}
		LA15_: ;
		result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n).info);
	}
	break;
	}
	{
		NimStringDesc* T21_;
		NimStringDesc* T22_;
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32)))) goto LA19_;
		T21_ = NIM_NIL;
		T22_ = NIM_NIL;
		T22_ = dollar___renderer_2116(n);
		T21_ = rawNewString((T22_ ? T22_->Sup.len : 0) + 38);
appendString(T21_, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_10));
appendString(T21_, T22_);
		liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T21_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_11, NIM_FALSE);
		goto BeforeRet_;
	}
	LA19_: ;
	{
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 25))&63U)))!=0)) goto LA25_;
		{
			if (!((130 & (*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).flags) == 0)) goto LA29_;
			liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_12), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_13, NIM_FALSE);
		}
		LA29_: ;
	}
	LA25_: ;
	fn = (*n)._kind_6.sons->data[((NI) 0)];
	T31_ = NIM_NIL;
	T32_ = NIM_NIL;
	{
		if (!((*fn).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA35_;
		T32_ = copyString((*(*(*fn)._kind_4.sym).name).s);
	}
	goto LA33_;
	LA35_: ;
	{
		T32_ = copyString(((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_14));
	}
	LA33_: ;
	T31_ = rawNewString((T32_ ? T32_->Sup.len : 0) + 7);
appendString(T31_, T32_);
appendString(T31_, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_15));
	name = T31_;
	T38_ = NIM_NIL;
	T38_ = getIdent__idents_152((*g).cache, name);
	T39_ = nextSymId__ast_3103(idgen);
	wrapperProc = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12), T38_, T39_, owner, (*fn).info, (*(*g).config).options);
	T40_ = NIM_NIL;
	T40_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_16));
	T41_ = nextSymId__ast_3103(idgen);
	threadParam = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3), T40_, T41_, wrapperProc, (*n).info, (*(*g).config).options);
	T42_ = NIM_NIL;
	T42_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_17));
	T43_ = nextSymId__ast_3103(idgen);
	argsParam = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3), T42_, T43_, wrapperProc, (*n).info, (*(*g).config).options);
	(*wrapperProc).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 42)) & 63);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ptrType;
		ptrType = getSysType__magicsys_60(g, (*n).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26));
		asgnRef((void**) (&(*threadParam).typ), ptrType);
		asgnRef((void**) (&(*argsParam).typ), ptrType);
		(*argsParam).position = ((NI) 1);
	}
	objType = createObj__lowerings_293(g, idgen, owner, (*n).info, NIM_TRUE);
	(*objType).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 2)) & 63);
	castExpr = createCastExpr__spawn_293(argsParam, objType, idgen);
	T45_ = NIM_NIL;
	T45_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_18));
	T46_ = nextSymId__ast_3103(idgen);
	scratchObj = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8), T45_, T46_, owner, (*n).info, (*(*g).config).options);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSectionB;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T48_;
		asgnRef((void**) (&(*scratchObj).typ), objType);
		(*scratchObj).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2)) & 63);
		varSectionB = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99), (*n).info);
		T48_ = NIM_NIL;
		T48_ = newSymNode__ast_3704(scratchObj);
		addVar__lowerings_63(varSectionB, T48_);
		add__ast_4798(result, varSectionB);
	}
	call = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*n).info, (*n).typ);
	{
		NIM_BOOL T51_;
		NIM_BOOL T53_;
		T51_ = (NIM_BOOL)0;
		T51_ = ((*fn).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155));
		if (T51_) goto LA52_;
		T53_ = (NIM_BOOL)0;
		T53_ = !(((*fn).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T53_)) goto LA54_;
		T53_ = ((*(*fn).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA54_: ;
		T51_ = T53_;
		LA52_: ;
		if (!T51_) goto LA55_;
		liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_19), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_20, NIM_FALSE);
	}
	LA55_: ;
	{
		NIM_BOOL T59_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* argType;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T63_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T64_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T65_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T66_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T67_;
		T59_ = (NIM_BOOL)0;
		T59_ = ((*fn).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T59_)) goto LA60_;
		T59_ = ((487424 &((NU32)1<<((NU)((*(*fn)._kind_4.sym).kind)&31U)))!=0);
		LA60_: ;
		if (!!(T59_)) goto LA61_;
		argType = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__Cdo77GqyHVvb4CeKFFZ13Q_21);
		T63_ = NIM_NIL;
		T63_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_22));
		T64_ = nextSymId__ast_3103(idgen);
		field = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), T63_, T64_, owner, (*n).info, (*(*g).config).options);
		asgnRef((void**) (&(*field).typ), argType);
		T65_ = NIM_NIL;
		T65_ = addField__lowerings_420(objType, field, (*g).cache, idgen);
		(void)(T65_);
		T66_ = NIM_NIL;
		T66_ = newDotExpr__lowerings_478(scratchObj, field);
		T67_ = NIM_NIL;
		T67_ = newFastAsgnStmt__lowerings_93(T66_, (*n)._kind_6.sons->data[((NI) 0)]);
		add__ast_4798(result, T67_);
		fn = indirectAccess__lowerings_616(castExpr, field, (*n).info);
	}
	goto LA57_;
	LA61_: ;
	{
		NIM_BOOL T69_;
		T69_ = (NIM_BOOL)0;
		T69_ = ((*fn).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T69_)) goto LA70_;
		T69_ = ((*(*fn)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		LA70_: ;
		if (!T69_) goto LA71_;
		liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_23), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Cdo77GqyHVvb4CeKFFZ13Q_24, NIM_FALSE);
	}
	goto LA57_;
	LA71_: ;
	LA57_: ;
	add__ast_4798(call, fn);
	varSection = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99), (*n).info);
	varInit = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n).info);
	{
		if (!(barrier == 0)) goto LA75_;
		setupArgsForConcurrency__spawn_310(g, n, objType, idgen, wrapperProc, scratchObj, castExpr, call, varSection, varInit, result);
	}
	goto LA73_;
	LA75_: ;
	{
		setupArgsForParallelism__spawn_380(g, n, objType, idgen, wrapperProc, scratchObj, castExpr, call, varSection, varInit, result);
	}
	LA73_: ;
	barrierAsExpr = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T82_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T83_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field_2;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T84_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T85_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T86_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T87_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T88_;
		if (!!((barrier == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA80_;
		T82_ = nextTypeId__ast_3122(idgen);
		typ = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21), T82_, owner);
		T83_ = NIM_NIL;
		T83_ = getCompilerProc__magicsys_145(g, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_31));
		rawAddSon__ast_4276(typ, (*T83_).typ, NIM_TRUE);
		T84_ = NIM_NIL;
		T84_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_32));
		T85_ = nextSymId__ast_3103(idgen);
		field_2 = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), T84_, T85_, owner, (*n).info, (*(*g).config).options);
		asgnRef((void**) (&(*field_2).typ), typ);
		T86_ = NIM_NIL;
		T86_ = addField__lowerings_420(objType, field_2, (*g).cache, idgen);
		(void)(T86_);
		T87_ = NIM_NIL;
		T87_ = newDotExpr__lowerings_478(scratchObj, field_2);
		T88_ = NIM_NIL;
		T88_ = newFastAsgnStmt__lowerings_93(T87_, barrier);
		add__ast_4798(result, T88_);
		barrierAsExpr = indirectAccess__lowerings_616(castExpr, field_2, (*n).info);
	}
	LA80_: ;
	fvField = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	fvAsExpr = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field_3;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T93_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T94_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T95_;
		NI T96_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T97_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T98_;
		if (!(spawnKind == ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 1))) goto LA91_;
		T93_ = NIM_NIL;
		T93_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_33));
		T94_ = nextSymId__ast_3103(idgen);
		field_3 = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), T93_, T94_, owner, (*n).info, (*(*g).config).options);
		asgnRef((void**) (&(*field_3).typ), retType);
		T95_ = NIM_NIL;
		T95_ = addField__lowerings_420(objType, field_3, (*g).cache, idgen);
		(void)(T95_);
		fvField = newDotExpr__lowerings_478(scratchObj, field_3);
		fvAsExpr = indirectAccess__lowerings_616(castExpr, field_3, (*n).info);
		T96_ = (NI)0;
		T96_ = len__ast_3155(spawnExpr);
		T97_ = NIM_NIL;
		T97_ = callProc__spawn_12((*spawnExpr)._kind_6.sons->data[(NI)(T96_ - ((NI) 1))]);
		T98_ = NIM_NIL;
		T98_ = newFastAsgnStmt__lowerings_93(fvField, T97_);
		add__ast_4798(result, T98_);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T103_;
			if (!(barrier == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA101_;
			T103_ = NIM_NIL;
			T103_ = callCodegenProc__lowerings_641(g, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_34), (*fvField).info, fvField, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
			add__ast_4798(result, T103_);
		}
		LA101_: ;
	}
	goto LA89_;
	LA91_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field_4;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T107_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T108_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T109_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T110_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T111_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T112_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T113_;
		if (!(spawnKind == ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 2))) goto LA105_;
		T107_ = NIM_NIL;
		T107_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_33));
		T108_ = nextSymId__ast_3103(idgen);
		field_4 = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), T107_, T108_, owner, (*n).info, (*(*g).config).options);
		T109_ = nextTypeId__ast_3122(idgen);
		asgnRef((void**) (&(*field_4).typ), newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21), T109_, (*objType).owner));
		rawAddSon__ast_4276((*field_4).typ, retType, NIM_TRUE);
		T110_ = NIM_NIL;
		T110_ = addField__lowerings_420(objType, field_4, (*g).cache, idgen);
		(void)(T110_);
		fvAsExpr = indirectAccess__lowerings_616(castExpr, field_4, (*n).info);
		T111_ = NIM_NIL;
		T111_ = newDotExpr__lowerings_478(scratchObj, field_4);
		T112_ = NIM_NIL;
		T112_ = genAddrOf__lowerings_626(dest, idgen, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
		T113_ = NIM_NIL;
		T113_ = newFastAsgnStmt__lowerings_93(T111_, T112_);
		add__ast_4798(result, T113_);
	}
	goto LA89_;
	LA105_: ;
	LA89_: ;
	createTypeBoundOps__liftdestructors_47(g, ((tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*) NIM_NIL), objType, (*n).info, idgen);
	createWrapperProc__spawn_137(g, fn, threadParam, argsParam, varSection, varInit, call, barrierAsExpr, fvAsExpr, idgen, spawnKind, wrapperProc);
	T114_ = NIM_NIL;
	T115_ = (NI)0;
	T115_ = len__ast_3155(spawnExpr);
	T116_ = NIM_NIL;
	T116_ = dollar___systemZdollars_3(T115_);
	T114_ = rawNewString((T116_ ? T116_->Sup.len : 0) + 8);
appendString(T114_, ((NimStringDesc*) &TM__Cdo77GqyHVvb4CeKFFZ13Q_46));
appendString(T114_, T116_);
	T117_ = NIM_NIL;
	T117_ = newSymNode__ast_3704(wrapperProc);
	T118_ = NIM_NIL;
	T118_ = newSymNode__ast_3704(scratchObj);
	T119_ = NIM_NIL;
	T119_ = genAddrOf__lowerings_626(T118_, idgen, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
	T120_ = NIM_NIL;
	T120_ = callCodegenProc__lowerings_641(g, T114_, (*wrapperProc).info, T117_, T119_, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), spawnExpr);
	add__ast_4798(result, T120_);
	{
		if (!(spawnKind == ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 1))) goto LA123_;
		add__ast_4798(result, fvField);
	}
	LA123_: ;
	}BeforeRet_: ;
	return result;
}
